@@ -34,9 +34,30 @@ class Sensor(Component):
   def __init__(self, board, pin):
     super(Sensor, self).__init__(board, pin)
 
+    self.threshold = 0.001
+
     self._pin.mode = pyfirmata.INPUT
     self._pin.enable_reporting()
 
+    self._old_value = self.value
+    self._board.on('data', self._handle_data)
+
+  def _handle_data(self):
+    value = self.value
+    high_value = value + self.threshold
+    low_value = value - self.threshold
+
+    if self._old_value < low_value or self._old_value > high_value:
+      self._old_value = value
+      self._handle_state_changed()
+
+  @debounce(0.005)
+  def _handle_state_changed(self):
+    self.emit('change')
+
+  def change(self, cb):
+    self.on('change', cb)
+
 class Led(Component):
 
   def __init__(self, board, pin):
@@ -70,6 +91,66 @@ class Led(Component):
 
     self._interval = setInterval(self.toggle, millis)
 
+  def brightness(self, value):
+    if self._pin.mode != pyfirmata.PWM:
+      self._pin.mode = pyfirmata.PWM
+
+    _new_value = value / 255.0
+
+    if _new_value == 0:
+      self._isOn = False
+    else:
+      self.isOn = True
+
+    self._pin.write(_new_value)
+    return self
+
+class RGBLed(EventEmitter):
+
+  def __init__(self, board, pins):
+    if not board:
+      raise ArduinoNotSuppliedException
+
+    # TODO: Check that pins is dict
+
+    super(RGBLed, self).__init__()
+
+    self._red = Led(board, pins["red"])
+    self._green = Led(board, pins["green"])
+    self._blue = Led(board, pins["blue"])
+
+  def off(self):
+    self._red.off(); self._green.off(); self._blue.off()
+    return self
+
+  def red(self):
+    self._red.on(); self._green.off(); self._blue.off()
+    return self
+
+  def green(self):
+    self._red.off(); self._green.on(); self._blue.off()
+    return self
+
+  def blue(self):
+    self._red.off(); self._green.off(); self._blue.on()
+    return self
+
+  def yellow(self):
+    self._red.on(); self._green.on(); self._blue.off()
+    return self
+
+  def cyan(self):
+    self._red.off(); self._green.on(); self._blue.on()
+    return self
+
+  def purple(self):
+    self._red.on(); self._green.off(); self._blue.on()
+    return self
+
+  def white(self):
+    self._red.on(); self._green.on(); self._blue.on()
+    return self
+
 class Buzzer(Led):
   pass
 
@@ -116,10 +197,10 @@ class Button(Sensor):
     self.on('hold', cb)
 
 class Servo(Component):
-  
+
   def __init__(self, board, pin):
     super(Servo, self).__init__(board, pin)
-    self._pin.mode = pyfirmata.SERVO       
+    self._pin.mode = pyfirmata.SERVO
 
   def set_position(self, degrees):
     if int(degrees) > 180 or int(degrees) < 0:
@@ -128,7 +209,7 @@ class Servo(Component):
 
   def move(self, degrees):
     self.set_position(self.value + int(degrees))
-    
+
   def center(self):
     self.set_position(90)
 
